@@ -1,3 +1,9 @@
+/*
+ * Copyright (C) 2005-2006, Tobias Klauser <tklauser@distanz.ch>
+ *
+ * Licensed under the terms of the GNU General Public License; version 2 or later.
+ */
+
 #ifndef _INOTAIL_H
 #define _INOTAIL_H
 
@@ -24,4 +30,10 @@ struct file_struct {
 # define dprintf(fmt, args...)
 #endif /* DEBUG */
 
+#ifdef __GNUC__
+# define unlikely(x) __builtin_expect(!!(x), 0)
+#else
+# define unlikely(x) (x)
+#endif /* __GNUC__ */
+
 #endif /* _INOTAIL_H */
